
# -*- coding: utf-8 -*-
"""
DO NOT EDIT THIS FILE!
It is automatically generated from opcfoundation.org schemas.
"""

from opcua import ua


def create_standard_address_space_Part4(server):
  
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18")
    node.BrowseName = ua.QualifiedName.from_string("ExpandedNodeId")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an absolute identifier for a node.")
    attrs.DisplayName = ua.LocalizedText("ExpandedNodeId")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=18")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=19")
    node.BrowseName = ua.QualifiedName.from_string("StatusCode")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a code representing the outcome of an operation by a Server.")
    attrs.DisplayName = ua.LocalizedText("StatusCode")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=19")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=23")
    node.BrowseName = ua.QualifiedName.from_string("DataValue")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a structure containing a value, a status code and timestamps.")
    attrs.DisplayName = ua.LocalizedText("DataValue")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=23")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=25")
    node.BrowseName = ua.QualifiedName.from_string("DiagnosticInfo")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a structure containing diagnostics associated with a StatusCode.")
    attrs.DisplayName = ua.LocalizedText("DiagnosticInfo")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=25")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=288")
    node.BrowseName = ua.QualifiedName.from_string("IntegerId")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A numeric identifier for an object.")
    attrs.DisplayName = ua.LocalizedText("IntegerId")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=288")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=307")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The types of applications.")
    attrs.DisplayName = ua.LocalizedText("ApplicationType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=307")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7597")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=307")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7597")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=307")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Server'),ua.LocalizedText('Client'),ua.LocalizedText('ClientAndServer'),ua.LocalizedText('DiscoveryServer')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=307")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=308")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationDescription")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes an application and how to find it.")
    attrs.DisplayName = ua.LocalizedText("ApplicationDescription")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=308")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=20998")
    node.BrowseName = ua.QualifiedName.from_string("VersionTime")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("VersionTime")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=20998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12189")
    node.BrowseName = ua.QualifiedName.from_string("ServerOnNetwork")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerOnNetwork")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=311")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationInstanceCertificate")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=15")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A certificate for an instance of an application.")
    attrs.DisplayName = ua.LocalizedText("ApplicationInstanceCertificate")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=311")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=302")
    node.BrowseName = ua.QualifiedName.from_string("MessageSecurityMode")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The type of security to use on a message.")
    attrs.DisplayName = ua.LocalizedText("MessageSecurityMode")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=302")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7595")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=302")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7595")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=302")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Invalid'),ua.LocalizedText('None'),ua.LocalizedText('Sign'),ua.LocalizedText('SignAndEncrypt')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=302")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=303")
    node.BrowseName = ua.QualifiedName.from_string("UserTokenType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The possible user token types.")
    attrs.DisplayName = ua.LocalizedText("UserTokenType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7596")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7596")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=303")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Anonymous'),ua.LocalizedText('UserName'),ua.LocalizedText('Certificate'),ua.LocalizedText('IssuedToken')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=303")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=304")
    node.BrowseName = ua.QualifiedName.from_string("UserTokenPolicy")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a user token that can be used with a server.")
    attrs.DisplayName = ua.LocalizedText("UserTokenPolicy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=304")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=312")
    node.BrowseName = ua.QualifiedName.from_string("EndpointDescription")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The description of a endpoint that can be used to access a server.")
    attrs.DisplayName = ua.LocalizedText("EndpointDescription")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=432")
    node.BrowseName = ua.QualifiedName.from_string("RegisteredServer")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The information required to register a server with a discovery server.")
    attrs.DisplayName = ua.LocalizedText("RegisteredServer")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=432")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12890")
    node.BrowseName = ua.QualifiedName.from_string("DiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for discovery configuration information.")
    attrs.DisplayName = ua.LocalizedText("DiscoveryConfiguration")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12890")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12891")
    node.BrowseName = ua.QualifiedName.from_string("MdnsDiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12890")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The discovery information needed for mDNS registration.")
    attrs.DisplayName = ua.LocalizedText("MdnsDiscoveryConfiguration")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12890")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=315")
    node.BrowseName = ua.QualifiedName.from_string("SecurityTokenRequestType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Indicates whether a token if being created or renewed.")
    attrs.DisplayName = ua.LocalizedText("SecurityTokenRequestType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7598")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7598")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=315")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Issue'),ua.LocalizedText('Renew')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7598")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7598")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7598")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=315")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=344")
    node.BrowseName = ua.QualifiedName.from_string("SignedSoftwareCertificate")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A software certificate with a digital signature.")
    attrs.DisplayName = ua.LocalizedText("SignedSoftwareCertificate")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=344")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=388")
    node.BrowseName = ua.QualifiedName.from_string("SessionAuthenticationToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=17")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A unique identifier for a session used to authenticate requests.")
    attrs.DisplayName = ua.LocalizedText("SessionAuthenticationToken")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=388")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=316")
    node.BrowseName = ua.QualifiedName.from_string("UserIdentityToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for a user identity token.")
    attrs.DisplayName = ua.LocalizedText("UserIdentityToken")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=316")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=319")
    node.BrowseName = ua.QualifiedName.from_string("AnonymousIdentityToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A token representing an anonymous user.")
    attrs.DisplayName = ua.LocalizedText("AnonymousIdentityToken")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=319")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=322")
    node.BrowseName = ua.QualifiedName.from_string("UserNameIdentityToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A token representing a user identified by a user name and password.")
    attrs.DisplayName = ua.LocalizedText("UserNameIdentityToken")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=322")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=325")
    node.BrowseName = ua.QualifiedName.from_string("X509IdentityToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A token representing a user identified by an X509 certificate.")
    attrs.DisplayName = ua.LocalizedText("X509IdentityToken")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=325")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=938")
    node.BrowseName = ua.QualifiedName.from_string("IssuedIdentityToken")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A token representing a user identified by a WS-Security XML token.")
    attrs.DisplayName = ua.LocalizedText("IssuedIdentityToken")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=938")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=348")
    node.BrowseName = ua.QualifiedName.from_string("NodeAttributesMask")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The bits used to specify default attributes for a new node.")
    attrs.DisplayName = ua.LocalizedText("NodeAttributesMask")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=348")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11881")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=348")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11881")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=348")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 0
    extobj.DisplayName.Text = 'None'
    extobj.Description.Text = 'No attribuites provided.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'AccessLevel'
    extobj.Description.Text = 'The access level attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'ArrayDimensions'
    extobj.Description.Text = 'The array dimensions attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4
    extobj.DisplayName.Text = 'BrowseName'
    extobj.Description.Text = 'The browse name attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 8
    extobj.DisplayName.Text = 'ContainsNoLoops'
    extobj.Description.Text = 'The contains no loops attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 16
    extobj.DisplayName.Text = 'DataType'
    extobj.Description.Text = 'The data type attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 32
    extobj.DisplayName.Text = 'Description'
    extobj.Description.Text = 'The description attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 64
    extobj.DisplayName.Text = 'DisplayName'
    extobj.Description.Text = 'The display name attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 128
    extobj.DisplayName.Text = 'EventNotifier'
    extobj.Description.Text = 'The event notifier attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 256
    extobj.DisplayName.Text = 'Executable'
    extobj.Description.Text = 'The executable attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 512
    extobj.DisplayName.Text = 'Historizing'
    extobj.Description.Text = 'The historizing attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 1024
    extobj.DisplayName.Text = 'InverseName'
    extobj.Description.Text = 'The inverse name attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2048
    extobj.DisplayName.Text = 'IsAbstract'
    extobj.Description.Text = 'The is abstract attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4096
    extobj.DisplayName.Text = 'MinimumSamplingInterval'
    extobj.Description.Text = 'The minimum sampling interval attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 8192
    extobj.DisplayName.Text = 'NodeClass'
    extobj.Description.Text = 'The node class attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 16384
    extobj.DisplayName.Text = 'NodeId'
    extobj.Description.Text = 'The node id attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 32768
    extobj.DisplayName.Text = 'Symmetric'
    extobj.Description.Text = 'The symmetric attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 65536
    extobj.DisplayName.Text = 'UserAccessLevel'
    extobj.Description.Text = 'The user access level attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 131072
    extobj.DisplayName.Text = 'UserExecutable'
    extobj.Description.Text = 'The user executable attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 262144
    extobj.DisplayName.Text = 'UserWriteMask'
    extobj.Description.Text = 'The user write mask attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 524288
    extobj.DisplayName.Text = 'ValueRank'
    extobj.Description.Text = 'The value rank attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 1048576
    extobj.DisplayName.Text = 'WriteMask'
    extobj.Description.Text = 'The write mask attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2097152
    extobj.DisplayName.Text = 'Value'
    extobj.Description.Text = 'The value attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4194304
    extobj.DisplayName.Text = 'DataTypeDefinition'
    extobj.Description.Text = 'The write mask attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 8388608
    extobj.DisplayName.Text = 'RolePermissions'
    extobj.Description.Text = 'The write mask attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 16777216
    extobj.DisplayName.Text = 'AccessRestrictions'
    extobj.Description.Text = 'The write mask attribute is specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 33554431
    extobj.DisplayName.Text = 'All'
    extobj.Description.Text = 'All attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26501220
    extobj.DisplayName.Text = 'BaseNode'
    extobj.Description.Text = 'All base attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26501348
    extobj.DisplayName.Text = 'Object'
    extobj.Description.Text = 'All object attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26503268
    extobj.DisplayName.Text = 'ObjectType'
    extobj.Description.Text = 'All object type attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26571383
    extobj.DisplayName.Text = 'Variable'
    extobj.Description.Text = 'All variable attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 28600438
    extobj.DisplayName.Text = 'VariableType'
    extobj.Description.Text = 'All variable type attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26632548
    extobj.DisplayName.Text = 'Method'
    extobj.Description.Text = 'All method attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26537060
    extobj.DisplayName.Text = 'ReferenceType'
    extobj.Description.Text = 'All reference type attributes are specified.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 26501356
    extobj.DisplayName.Text = 'View'
    extobj.Description.Text = 'All view attributes are specified.'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11881")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11881")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11881")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=348")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=376")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesItem")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A request to add a node to the server address space.")
    attrs.DisplayName = ua.LocalizedText("AddNodesItem")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=376")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=379")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesItem")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A request to add a reference to the server address space.")
    attrs.DisplayName = ua.LocalizedText("AddReferencesItem")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=379")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=382")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesItem")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A request to delete a node to the server address space.")
    attrs.DisplayName = ua.LocalizedText("DeleteNodesItem")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=382")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=385")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesItem")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A request to delete a node from the server address space.")
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesItem")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=385")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=347")
    node.BrowseName = ua.QualifiedName.from_string("AttributeWriteMask")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Define bits used to indicate which attributes are writable.")
    attrs.DisplayName = ua.LocalizedText("AttributeWriteMask")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=347")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15036")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=347")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15036")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=347")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('AccessLevel'),ua.LocalizedText('ArrayDimensions'),ua.LocalizedText('BrowseName'),ua.LocalizedText('ContainsNoLoops'),ua.LocalizedText('DataType'),ua.LocalizedText('Description'),ua.LocalizedText('DisplayName'),ua.LocalizedText('EventNotifier'),ua.LocalizedText('Executable'),ua.LocalizedText('Historizing'),ua.LocalizedText('InverseName'),ua.LocalizedText('IsAbstract'),ua.LocalizedText('MinimumSamplingInterval'),ua.LocalizedText('NodeClass'),ua.LocalizedText('NodeId'),ua.LocalizedText('Symmetric'),ua.LocalizedText('UserAccessLevel'),ua.LocalizedText('UserExecutable'),ua.LocalizedText('UserWriteMask'),ua.LocalizedText('ValueRank'),ua.LocalizedText('WriteMask'),ua.LocalizedText('ValueForVariableType'),ua.LocalizedText('DataTypeDefinition'),ua.LocalizedText('RolePermissions'),ua.LocalizedText('AccessRestrictions'),ua.LocalizedText('AccessLevelEx')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=347")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=521")
    node.BrowseName = ua.QualifiedName.from_string("ContinuationPoint")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=15")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An identifier for a suspended query or browse operation.")
    attrs.DisplayName = ua.LocalizedText("ContinuationPoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=521")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=537")
    node.BrowseName = ua.QualifiedName.from_string("RelativePathElement")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An element in a relative path.")
    attrs.DisplayName = ua.LocalizedText("RelativePathElement")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=537")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=540")
    node.BrowseName = ua.QualifiedName.from_string("RelativePath")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A relative path constructed from reference types and browse names.")
    attrs.DisplayName = ua.LocalizedText("RelativePath")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=540")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=289")
    node.BrowseName = ua.QualifiedName.from_string("Counter")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A monotonically increasing value.")
    attrs.DisplayName = ua.LocalizedText("Counter")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=289")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=291")
    node.BrowseName = ua.QualifiedName.from_string("NumericRange")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Specifies a range of array indexes.")
    attrs.DisplayName = ua.LocalizedText("NumericRange")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=291")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=292")
    node.BrowseName = ua.QualifiedName.from_string("Time")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A time value specified as HH:MM:SS.SSS.")
    attrs.DisplayName = ua.LocalizedText("Time")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=292")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=293")
    node.BrowseName = ua.QualifiedName.from_string("Date")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=13")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A date value.")
    attrs.DisplayName = ua.LocalizedText("Date")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=293")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=331")
    node.BrowseName = ua.QualifiedName.from_string("EndpointConfiguration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointConfiguration")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=331")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=576")
    node.BrowseName = ua.QualifiedName.from_string("FilterOperator")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FilterOperator")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7605")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7605")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=576")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Equals'),ua.LocalizedText('IsNull'),ua.LocalizedText('GreaterThan'),ua.LocalizedText('LessThan'),ua.LocalizedText('GreaterThanOrEqual'),ua.LocalizedText('LessThanOrEqual'),ua.LocalizedText('Like'),ua.LocalizedText('Not'),ua.LocalizedText('Between'),ua.LocalizedText('InList'),ua.LocalizedText('And'),ua.LocalizedText('Or'),ua.LocalizedText('Cast'),ua.LocalizedText('InView'),ua.LocalizedText('OfType'),ua.LocalizedText('RelatedTo'),ua.LocalizedText('BitwiseAnd'),ua.LocalizedText('BitwiseOr')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7605")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7605")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7605")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=576")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=583")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilterElement")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilterElement")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=583")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=586")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilter")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilter")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=586")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=589")
    node.BrowseName = ua.QualifiedName.from_string("FilterOperand")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FilterOperand")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=589")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=592")
    node.BrowseName = ua.QualifiedName.from_string("ElementOperand")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ElementOperand")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=592")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=595")
    node.BrowseName = ua.QualifiedName.from_string("LiteralOperand")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("LiteralOperand")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=598")
    node.BrowseName = ua.QualifiedName.from_string("AttributeOperand")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AttributeOperand")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=598")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=601")
    node.BrowseName = ua.QualifiedName.from_string("SimpleAttributeOperand")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SimpleAttributeOperand")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=601")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=659")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEvent")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEvent")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=659")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11234")
    node.BrowseName = ua.QualifiedName.from_string("HistoryUpdateType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryUpdateType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11884")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11884")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11234")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'Insert'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'Replace'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 3
    extobj.DisplayName.Text = 'Update'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4
    extobj.DisplayName.Text = 'Delete'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11234")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11293")
    node.BrowseName = ua.QualifiedName.from_string("PerformUpdateType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("PerformUpdateType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11293")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11885")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11293")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11885")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11293")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'Insert'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'Replace'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 3
    extobj.DisplayName.Text = 'Update'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4
    extobj.DisplayName.Text = 'Remove'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11885")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11885")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11885")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11293")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=719")
    node.BrowseName = ua.QualifiedName.from_string("MonitoringFilter")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoringFilter")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=719")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=725")
    node.BrowseName = ua.QualifiedName.from_string("EventFilter")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=719")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EventFilter")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=725")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=719")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=948")
    node.BrowseName = ua.QualifiedName.from_string("AggregateConfiguration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AggregateConfiguration")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=948")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=920")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEventFieldList")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEventFieldList")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=920")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=310")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=308")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=310")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=308")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=310")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7665")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=310")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12207")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12189")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12189")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12213")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=306")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=304")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=304")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7662")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=314")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=312")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7668")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=434")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=432")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=434")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=432")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=434")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7782")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=434")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12900")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12890")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12890")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12902")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12901")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12891")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12901")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12891")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12901")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12905")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12901")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=346")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=344")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=346")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=344")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=346")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7698")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=346")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=318")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=318")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=318")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7671")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=318")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=321")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=319")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=321")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=319")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=321")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7674")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=321")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=324")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=322")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=324")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=322")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=324")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7677")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=324")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=327")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=325")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=327")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=325")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=327")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7680")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=327")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=940")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=938")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=940")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=938")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=940")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7683")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=940")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=378")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=376")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=376")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7728")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=381")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=379")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=379")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7731")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=384")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=382")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=382")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7734")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=387")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=385")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=385")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7737")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=539")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=537")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=539")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=537")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=539")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12718")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=539")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=542")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=540")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=542")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=540")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=542")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12721")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=542")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=333")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=331")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=333")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=331")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=333")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7686")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=333")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=585")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=583")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=583")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7929")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=588")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=586")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=586")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7932")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=591")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7935")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=594")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=592")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=592")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7938")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=597")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=595")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=595")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7941")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=597")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=600")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=598")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=600")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=598")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=600")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7944")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=600")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=603")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=601")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=603")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=601")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=603")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7947")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=603")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=661")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=659")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=661")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=659")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=661")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8004")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=661")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=721")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=719")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=719")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8067")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=727")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=725")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=727")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=725")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=727")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8073")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=727")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=950")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=948")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=948")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8076")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=922")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=920")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=922")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=920")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=922")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=922")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=309")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=308")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=308")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8300")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12195")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12189")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12189")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12201")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=305")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=304")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=305")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=304")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=305")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8297")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=305")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=313")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=312")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8303")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=433")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=432")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=433")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=432")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=433")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8417")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=433")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12892")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12890")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12890")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12894")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12893")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12891")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12891")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=345")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=344")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=345")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=344")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=345")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8333")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=345")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=317")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=317")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=317")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8306")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=317")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=320")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=319")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=320")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=319")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=320")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8309")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=320")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=323")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=322")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=323")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=322")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=323")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=323")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=326")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=325")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=326")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=325")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=326")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8315")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=326")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=939")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=938")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=939")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=938")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=939")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8318")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=939")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=377")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=376")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=376")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8363")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=380")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=379")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=379")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8366")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=383")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=382")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=382")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8369")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=386")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=385")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=385")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8372")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=538")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=537")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=538")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=537")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=538")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12712")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=538")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=541")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=540")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=541")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=540")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=541")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12715")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=541")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=332")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=331")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=332")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=331")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=332")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8321")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=332")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=584")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=583")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=583")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8564")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=587")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=586")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=586")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8567")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=590")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8570")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=593")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=592")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=592")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8573")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=596")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=595")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=595")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8576")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=596")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=599")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=598")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=599")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=598")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=599")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8579")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=599")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=602")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=601")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=602")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=601")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=602")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8582")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=602")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=660")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=659")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=660")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=659")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=660")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8639")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=660")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=720")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=719")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=719")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8702")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=726")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=725")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=726")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=725")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=726")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8708")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=726")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=949")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=948")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=948")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8711")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=921")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=920")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=921")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=920")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=921")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8807")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=921")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15087")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=308")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=308")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15095")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12189")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12189")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15098")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=304")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=304")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15099")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=312")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15102")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=432")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=432")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15105")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12890")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12890")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15106")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12891")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12891")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15136")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=344")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=344")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15140")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=316")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=316")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15141")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=319")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=319")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15142")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=322")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=322")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15143")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=325")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=325")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15144")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=938")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=938")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15165")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=376")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=376")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15169")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=379")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=379")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15172")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=382")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=382")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15175")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=385")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=385")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15188")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=537")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15188")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=537")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15188")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15189")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=540")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=540")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15199")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=331")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=331")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15204")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=583")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=583")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15205")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=586")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=586")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15206")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=589")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=589")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15207")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=592")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=592")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15208")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=595")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=595")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15209")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=598")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=598")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15210")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=601")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15210")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=601")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15210")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15273")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=659")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15273")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=659")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15273")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15293")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=719")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15293")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=719")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15293")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15295")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=725")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=725")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15304")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=948")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15304")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=948")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15304")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15349")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=920")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15349")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=920")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15349")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
